@@ -75,7 +75,7 @@ import org.joda.time.tz.ZoneInfoProvider;
  * </ul>
  * <p>
  * Unlike the Java TimeZone class, DateTimeZone is immutable. It also only
- * supports long format time zone ids. Thus EST and ECT are not accepted.
+ * supports long format time zone ids. Thus PST and ECT are not accepted.
  * However, the factory that accepts a TimeZone will attempt to convert from
  * the old short id to a suitable long id.
  * <p>
@@ -127,6 +127,11 @@ public abstract class DateTimeZone implements Serializable {
      */
     private static final AtomicReference<DateTimeZone> cDefault =
                     new AtomicReference<DateTimeZone>();
+    /**
+     * The default TZ data path
+     * This is the default classpath location containing the compiled data files.
+     */
+    public static final String DEFAULT_TZ_DATA_PATH = "org/joda/time/tz/data";
 
     //-----------------------------------------------------------------------
     /**
@@ -504,7 +509,12 @@ public abstract class DateTimeZone implements Serializable {
             String providerClass = System.getProperty("org.joda.time.DateTimeZone.Provider");
             if (providerClass != null) {
                 try {
-                    Provider provider = (Provider) Class.forName(providerClass).newInstance();
+                    // do not initialize the class until the type has been checked
+                    Class<?> cls = Class.forName(providerClass, false, DateTimeZone.class.getClassLoader());
+                    if (!Provider.class.isAssignableFrom(cls)) {
+                        throw new IllegalArgumentException("System property referred to class that does not implement " + Provider.class);
+                    }
+                    Provider provider = cls.asSubclass(Provider.class).getConstructor().newInstance();
                     return validateProvider(provider);
                 } catch (Exception ex) {
                     throw new RuntimeException(ex);
@@ -529,7 +539,7 @@ public abstract class DateTimeZone implements Serializable {
         }
         // approach 3
         try {
-            Provider provider = new ZoneInfoProvider("org/joda/time/tz/data");
+            Provider provider = new ZoneInfoProvider(DEFAULT_TZ_DATA_PATH);
             return validateProvider(provider);
         } catch (Exception ex) {
             ex.printStackTrace();
@@ -593,7 +603,12 @@ public abstract class DateTimeZone implements Serializable {
             String providerClass = System.getProperty("org.joda.time.DateTimeZone.NameProvider");
             if (providerClass != null) {
                 try {
-                    nameProvider = (NameProvider) Class.forName(providerClass).newInstance();
+                    // do not initialize the class until the type has been checked
+                    Class<?> cls = Class.forName(providerClass, false, DateTimeZone.class.getClassLoader());
+                    if (!NameProvider.class.isAssignableFrom(cls)) {
+                        throw new IllegalArgumentException("System property referred to class that does not implement " + NameProvider.class);
+                    }
+                    nameProvider = cls.asSubclass(NameProvider.class).getConstructor().newInstance();
                 } catch (Exception ex) {
                     throw new RuntimeException(ex);
                 }
